@@ -497,6 +497,8 @@ static QString kwinService()
     return u"org.kde.KWin"_s;
 }
 
+constexpr int kwinDBusTimeout = 3000;
+
 static QString kwinInputCaptureInterface()
 {
     return u"org.kde.KWin.EIS.InputCapture"_s;
@@ -540,24 +542,24 @@ QDBusPendingReply<void> InputCaptureSession::enable()
 {
     auto msg = QDBusMessage::createMethodCall(kwinService(), m_kwinInputCapture.path(), kwinInputCaptureInterface(), u"enable"_s);
     msg << QVariant::fromValue(m_barriers);
-    return QDBusConnection::sessionBus().asyncCall(msg);
+    return QDBusConnection::sessionBus().asyncCall(msg, kwinDBusTimeout);
 }
 
 QDBusPendingReply<void> InputCaptureSession::disable()
 {
     auto msg = QDBusMessage::createMethodCall(kwinService(), m_kwinInputCapture.path(), kwinInputCaptureInterface(), u"disable"_s);
-    return QDBusConnection::sessionBus().asyncCall(msg);
+    return QDBusConnection::sessionBus().asyncCall(msg, kwinDBusTimeout);
 }
 
 QDBusPendingReply<void> InputCaptureSession::release(const QPointF &cusorPosition, bool applyPosition)
 {
     auto msg = QDBusMessage::createMethodCall(kwinService(), m_kwinInputCapture.path(), kwinInputCaptureInterface(), u"release"_s);
     msg << cusorPosition << applyPosition;
-    return QDBusConnection::sessionBus().asyncCall(msg);
+    return QDBusConnection::sessionBus().asyncCall(msg, kwinDBusTimeout);
 }
 
 QDBusPendingReply<QDBusUnixFileDescriptor> InputCaptureSession::connectToEIS()
 {
     auto msg = QDBusMessage::createMethodCall(kwinService(), m_kwinInputCapture.path(), kwinInputCaptureInterface(), u"connectToEIS"_s);
-    return QDBusConnection::sessionBus().asyncCall(msg);
+    return QDBusConnection::sessionBus().asyncCall(msg, kwinDBusTimeout);
 }
